==> haskell-stm-containers-1.2.1.1-150.1-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-containers
version:              1.2.1.1
visibility:           public
id:                   stm-containers-1.2.1.1-Hz65IINTWZ7BOmg5g07dNl
key:                  stm-containers-1.2.1.1-Hz65IINTWZ7BOmg5g07dNl
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  723941daecd233d17ed477941967f351
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/stm-containers-1.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stm-containers-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stm-containers-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.1.1-Hz65IINTWZ7BOmg5g07dNl
depends:
    base-4.18.2.1 deferred-folds-0.9.18.7-3YASkbivcMDDaPil1p3K3o
    focus-1.0.3.2-dqVNbqCJwxApDYKekKDIO
    hashable-1.4.7.0-DKTv0aQgcZmBEMi2BPTV4Z
    list-t-1.0.5.7-AhA7x2MdeKdKv2uigYKj0T
    stm-hamt-1.2.1.1-6Q99VA88jPfA6FGDMnAfhP transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-stm-containers-1.2.1.1-151-loong64.pkg.tar.zst: usr/share/haskell/register/haskell-stm-containers.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
printf '%s' 'name:                 stm-containers
version:              1.2.1.1
visibility:           public
id:                   stm-containers-1.2.1.1-ERO4CbZuQhYK0vXacIine9
key:                  stm-containers-1.2.1.1-ERO4CbZuQhYK0vXacIine9
license:              MIT
copyright:            (c) 2014, Nikita Volkov
maintainer:           Nikita Volkov <nikita.y.volkov@mail.ru>
author:               Nikita Volkov <nikita.y.volkov@mail.ru>
homepage:             https://github.com/nikita-volkov/stm-containers
synopsis:             Containers for STM
description:
    This library is based on an STM-specialized implementation of
    Hash Array Mapped Trie.
    It provides efficient implementations of @Map@, @Set@
    and other data structures,
    which starting from version @1@ perform even better than their counterparts from \"unordered-containers\",
    but also scale well on concurrent access patterns.
    .
    For details on performance of the library, which are a bit outdated, see
    <http://nikita-volkov.github.io/stm-containers/ this blog post>.

category:             Data Structures, STM, Concurrency
abi:                  b190596ae198e613dcf1e18d24a223d0
exposed:              True
exposed-modules:
    StmContainers.Bimap StmContainers.Map StmContainers.Multimap
    StmContainers.Set

hidden-modules:       StmContainers.Prelude
import-dirs:          /usr/lib/ghc-9.6.6/site-local/stm-containers-1.2.1.1
library-dirs:         /usr/lib/ghc-9.6.6/site-local/stm-containers-1.2.1.1
library-dirs-static:  /usr/lib/ghc-9.6.6/site-local/stm-containers-1.2.1.1
dynamic-library-dirs: /usr/lib
data-dir:             /usr/share/haskell-stm-containers
hs-libraries:         HSstm-containers-1.2.1.1-ERO4CbZuQhYK0vXacIine9
depends:
    base-4.18.2.1 deferred-folds-0.9.18.7-AQVjI6sElLgFSTBjW4DXpU
    focus-1.0.3.2-K7eYaaN3rLJIOKNkem96pr
    hashable-1.4.7.0-1GSULm1uRgQBgX6mu6tvYD
    list-t-1.0.5.7-FrIBwXDu8V5JPdGMNO7zz5
    stm-hamt-1.2.1.1-HHAwtfZaTzEBCKUhhMngKz transformers-0.6.1.0

haddock-interfaces:
    /usr/share/doc/haskell-stm-containers/html/stm-containers.haddock

haddock-html:         /usr/share/doc/haskell-stm-containers/html
' | '/usr/bin/ghc-pkg-9.6.6' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
